/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.gobblin.service.modules.orchestration;

import java.util.Map;

import lombok.AllArgsConstructor;
import lombok.Getter;


/**
 * This status captures execution details returned by {@link AzkabanClient#fetchFlowExecution(String)}
 *
 * The execution details are captured by {@link Execution}
 */
public class AzkabanFetchExecuteFlowStatus extends AzkabanClientStatus<AzkabanFetchExecuteFlowStatus.Execution> {
  public AzkabanFetchExecuteFlowStatus(AzkabanFetchExecuteFlowStatus.Execution exec) {
    super(exec);
  }

  @Getter
  @AllArgsConstructor
  public static class Execution {
    Map<String, String> map;
  }
}
